@@ -22,13 +22,13 @@
 #include <string.h>
 #include "array.h"
 #include "error.h"
+#include "memory.h"
 #include "text.h"
 #include "unicode.h"
-#include "xalloc.h"
 #include "render.h"
 
 
-static void render_grow(struct render *r, int nadd)
+static void corpus_render_grow(struct corpus_render *r, int nadd)
 {
 	void *base = r->string;
 	int size = r->length_max + 1;
@@ -42,8 +42,8 @@ static void render_grow(struct render *r, int nadd)
 		return;
 	}
 
-	if ((err = array_grow(&base, &size, sizeof(*r->string),
-			      r->length + 1, nadd))) {
+	if ((err = corpus_array_grow(&base, &size, sizeof(*r->string),
+				     r->length + 1, nadd))) {
 		r->error = err;
 		return;
 	}
@@ -53,14 +53,14 @@ static void render_grow(struct render *r, int nadd)
 }
 
 
-int render_init(struct render *r, int escape_flags)
+int corpus_render_init(struct corpus_render *r, int escape_flags)
 {
 	int err;
 
-	r->string = xmalloc(1);
+	r->string = corpus_malloc(1);
 	if (!r->string) {
-		err = ERROR_NOMEM;
-		logmsg(err, "failed initializing render object");
+		err = CORPUS_ERROR_NOMEM;
+		corpus_log(err, "failed initializing render object");
 		return err;
 	}
 
@@ -74,19 +74,19 @@ int render_init(struct render *r, int escape_flags)
 	r->newline = "\n";
 	r->newline_length = (int)strlen(r->newline);
 
-	render_clear(r);
+	corpus_render_clear(r);
 
 	return 0;
 }
 
 
-void render_destroy(struct render *r)
+void corpus_render_destroy(struct corpus_render *r)
 {
-	free(r->string);
+	corpus_free(r->string);
 }
 
 
-void render_clear(struct render *r)
+void corpus_render_clear(struct corpus_render *r)
 {
 	r->string[0] = '\0';
 	r->length = 0;
@@ -96,7 +96,7 @@ void render_clear(struct render *r)
 }
 
 
-int render_set_escape(struct render *r, int flags)
+int corpus_render_set_escape(struct corpus_render *r, int flags)
 {
 	int oldflags = r->escape_flags;
 	r->escape_flags = flags;
@@ -104,15 +104,16 @@ int render_set_escape(struct render *r, int flags)
 }
 
 
-const char *render_set_tab(struct render *r, const char *tab)
+const char *corpus_render_set_tab(struct corpus_render *r, const char *tab)
 {
 	const char *oldtab = r->tab;
 	size_t len;
 	assert(tab);
 
 	if ((len = strlen(tab)) >= INT_MAX) {
-		r->error = ERROR_OVERFLOW;
-		logmsg(r->error, "tab string length exceeds maximum (%d)", INT_MAX - 1);
+		r->error = CORPUS_ERROR_OVERFLOW;
+		corpus_log(r->error, "tab string length exceeds maximum (%d)",
+			   INT_MAX - 1);
 
 	} else {
 		r->tab = tab;
@@ -123,15 +124,16 @@ const char *render_set_tab(struct render *r, const char *tab)
 }
 
 
-const char *render_set_newline(struct render *r, const char *newline)
+const char *corpus_render_set_newline(struct corpus_render *r,
+				      const char *newline)
 {
 	const char *oldnewline = r->newline;
 	size_t len;
 	assert(newline);
 
 	if ((len = strlen(newline)) >= INT_MAX) {
-		r->error = ERROR_OVERFLOW;
-		logmsg(r->error, "newline string length exceeds maximum (%d)", INT_MAX - 1);
+		r->error = CORPUS_ERROR_OVERFLOW;
+		corpus_log(r->error, "newline string length exceeds maximum (%d)", INT_MAX - 1);
 	} else {
 		r->newline = newline;
 		r->newline_length = (int)len;
@@ -141,14 +143,14 @@ const char *render_set_newline(struct render *r, const char *newline)
 }
 
 
-void render_indent(struct render *r, int nlevel)
+void corpus_render_indent(struct corpus_render *r, int nlevel)
 {
 	r->indent += nlevel;
 	assert(r->indent >= 0);
 }
 
 
-void render_newlines(struct render *r, int nline)
+void corpus_render_newlines(struct corpus_render *r, int nline)
 {
 	char *end;
 	int i;
@@ -158,7 +160,7 @@ void render_newlines(struct render *r, int nline)
 	}
 
 	for (i = 0; i < nline; i++) {
-		render_grow(r, r->newline_length);
+		corpus_render_grow(r, r->newline_length);
 		if (r->error) {
 			return;
 		}
@@ -171,7 +173,7 @@ void render_newlines(struct render *r, int nline)
 }
 
 
-static void maybe_indent(struct render *r)
+static void maybe_indent(struct corpus_render *r)
 {
 	int ntab = r->indent;
 	char *end;
@@ -186,7 +188,7 @@ static void maybe_indent(struct render *r)
 	}
 
 	for (i = 0; i < ntab; i++) {
-		render_grow(r, r->tab_length);
+		corpus_render_grow(r, r->tab_length);
 		if (r->error) {
 			return;
 		}
@@ -200,7 +202,7 @@ static void maybe_indent(struct render *r)
 }
 
 
-void render_char(struct render *r, uint32_t ch)
+void corpus_render_char(struct corpus_render *r, uint32_t ch)
 {
 	char *end;
 	uint8_t *uend;
@@ -218,15 +220,15 @@ void render_char(struct render *r, uint32_t ch)
 	// maximum character expansion:
 	// \uXXXX\uXXXX
 	// 123456789012
-	render_grow(r, 12);
+	corpus_render_grow(r, 12);
 	if (r->error) {
 		return;
 	}
 
 	end = r->string + r->length;
-	if (IS_ASCII(ch)) {
+	if (CORPUS_IS_ASCII(ch)) {
 		if ((ch <= 0x1F || ch == 0x7F)
-				&& r->escape_flags | ESCAPE_CONTROL) {
+				&& r->escape_flags | CORPUS_ESCAPE_CONTROL) {
 			switch (ch) {
 			case '\b':
 				end[0] = '\\'; end[1] = 'b'; end[2] = '\0';
@@ -254,33 +256,33 @@ void render_char(struct render *r, uint32_t ch)
 				break;
 			}
 		} else {
-			end[0] = ch;
+			end[0] = (char)ch;
 			end[1] = '\0';
 			r->length++;
 		}
-	} else if (ch <= 0x9F && r->escape_flags | ESCAPE_CONTROL) {
+	} else if (ch <= 0x9F && r->escape_flags | CORPUS_ESCAPE_CONTROL) {
 		sprintf(end, "\\u%04x", ch);
 		r->length += 6;
-	} else if (r->escape_flags | ESCAPE_UTF8) {
-		if (UTF16_ENCODE_LEN(ch) == 1) {
+	} else if (r->escape_flags | CORPUS_ESCAPE_UTF8) {
+		if (CORPUS_UTF16_ENCODE_LEN(ch) == 1) {
 			sprintf(end, "\\u%04x", ch);
 			r->length += 6;
 		} else {
-			hi = UTF16_HIGH(ch);
-			lo = UTF16_LOW(ch);
+			hi = CORPUS_UTF16_HIGH(ch);
+			lo = CORPUS_UTF16_LOW(ch);
 			sprintf(end, "\\u%04x\\u%04x", hi, lo);
 			r->length += 12;
 		}
 	} else {
 		uend = (uint8_t *)end;
-		encode_utf8(ch, &uend);
+		corpus_encode_utf8(ch, &uend);
 		*uend = '\0';
-		r->length += UTF8_ENCODE_LEN(ch);
+		r->length += CORPUS_UTF8_ENCODE_LEN(ch);
 	}
 }
 
 
-void render_string(struct render *r, const char *str)
+void corpus_render_string(struct corpus_render *r, const char *str)
 {
 	const uint8_t *ptr = (const uint8_t *)str;
 	uint32_t ch;
@@ -290,11 +292,11 @@ void render_string(struct render *r, const char *str)
 	}
 
 	while (1) {
-		decode_utf8(&ptr, &ch);
+		corpus_decode_utf8(&ptr, &ch);
 		if (ch == 0) {
 			return;
 		}
-		render_char(r, ch);
+		corpus_render_char(r, ch);
 		if (r->error) {
 			return;
 		}
@@ -302,7 +304,7 @@ void render_string(struct render *r, const char *str)
 }
 
 
-void render_printf(struct render *r, const char *format, ...)
+void corpus_render_printf(struct corpus_render *r, const char *format, ...)
 {
 	va_list ap, ap2;
 	int err, len;
@@ -316,13 +318,14 @@ void render_printf(struct render *r, const char *format, ...)
 
 	len = vsnprintf(NULL, 0, format, ap);
 	if (len < 0) {
-		err = ERROR_OS;
-		logmsg(err, "printf formatting error: %s", strerror(errno));
+		err = CORPUS_ERROR_OS;
+		corpus_log(err, "printf formatting error: %s",
+			   strerror(errno));
 		r->error = err;
 		goto out;
 	}
 
-	render_grow(r, len);
+	corpus_render_grow(r, len);
 	if (r->error) {
 		goto out;
 	}
@@ -336,17 +339,18 @@ out:
 }
 
 
-void render_text(struct render *r, const struct text *text)
+void corpus_render_text(struct corpus_render *r,
+			const struct corpus_text *text)
 {
-	struct text_iter it;
+	struct corpus_text_iter it;
 
 	if (r->error) {
 		return;
 	}
 
-	text_iter_make(&it, text);
-	while (text_iter_advance(&it)) {
-		render_char(r, it.current);
+	corpus_text_iter_make(&it, text);
+	while (corpus_text_iter_advance(&it)) {
+		corpus_render_char(r, it.current);
 		if (r->error) {
 			return;
 		}
