@@ -19,13 +19,14 @@
 #include "sentscan.h"
 
 
-void sentscan_make(struct sentscan *scan, const struct text *text)
+void corpus_sentscan_make(struct corpus_sentscan *scan,
+			  const struct corpus_text *text)
 {
 	scan->text = *text;
-	scan->text_attr = text->attr & ~TEXT_SIZE_MASK;
+	scan->text_attr = text->attr & ~CORPUS_TEXT_SIZE_MASK;
 
-	text_iter_make(&scan->iter, text);
-	sentscan_reset(scan);
+	corpus_text_iter_make(&scan->iter, text);
+	corpus_sentscan_reset(scan);
 }
 
 
@@ -37,7 +38,7 @@ void sentscan_make(struct sentscan *scan, const struct text *text)
 		scan->attr = scan->iter.attr; \
 		scan->prop = scan->iter_prop; \
 		scan->iter_ptr = scan->iter.ptr; \
-		if (text_iter_advance(&scan->iter)) { \
+		if (corpus_text_iter_advance(&scan->iter)) { \
 			scan->iter_prop = sent_break(scan->iter.current); \
 		} else { \
 			scan->iter_prop = -1; \
@@ -54,7 +55,7 @@ void sentscan_make(struct sentscan *scan, const struct text *text)
 				|| scan->iter_prop == SENT_BREAK_FORMAT) { \
 			scan->attr |= scan->iter.attr; \
 			scan->iter_ptr = scan->iter.ptr; \
-			if (text_iter_advance(&scan->iter)) { \
+			if (corpus_text_iter_advance(&scan->iter)) { \
 				scan->iter_prop = \
 					sent_break(scan->iter.current); \
 			} else { \
@@ -83,22 +84,22 @@ void sentscan_make(struct sentscan *scan, const struct text *text)
 	} while (0)
 
 
-void sentscan_reset(struct sentscan *scan)
+void corpus_sentscan_reset(struct corpus_sentscan *scan)
 {
 	scan->current.ptr = 0;
 	scan->current.attr = 0;
-	scan->type = SENT_NONE;
+	scan->type = CORPUS_SENT_NONE;
 
-	text_iter_reset(&scan->iter);
+	corpus_text_iter_reset(&scan->iter);
 	scan->ptr = scan->iter.ptr;
 
-	if (text_iter_advance(&scan->iter)) {
+	if (corpus_text_iter_advance(&scan->iter)) {
 		scan->code = scan->iter.current;
 		scan->attr = scan->iter.attr;
 		scan->prop = sent_break(scan->code);
 
 		scan->iter_ptr = scan->iter.ptr;
-		if (text_iter_advance(&scan->iter)) {
+		if (corpus_text_iter_advance(&scan->iter)) {
 			scan->iter_prop = sent_break(scan->iter.current);
 		} else {
 			scan->iter_prop = -1;
@@ -115,10 +116,10 @@ void sentscan_reset(struct sentscan *scan)
 }
 
 
-static int has_future_lower(const struct sentscan *scan)
+static int has_future_lower(const struct corpus_sentscan *scan)
 {
-	struct text_iter iter;
-	int prop;
+	struct corpus_text_iter iter;
+	int prop, ret;
 
 	if (scan->iter_prop < 0) {
 		return 0;
@@ -136,28 +137,35 @@ static int has_future_lower(const struct sentscan *scan)
 		case SENT_BREAK_LF:
 		case SENT_BREAK_STERM:
 		case SENT_BREAK_ATERM:
-			return 0;
+			ret = 0;
+			goto out;
+
 		case SENT_BREAK_LOWER:
-			return 1;
+			ret = 1;
+			goto out;
+
 		default:
 			break;
 		}
-		if (text_iter_advance(&iter)) {
+
+		if (corpus_text_iter_advance(&iter)) {
 			prop = sent_break(iter.current);
 		} else {
-			return 0;
+			ret = 0;
+			goto out;
 		}
 	}
 
-	return 0;
+out:
+	return ret;
 }
 
 
-int sentscan_advance(struct sentscan *scan)
+int corpus_sentscan_advance(struct corpus_sentscan *scan)
 {
 	scan->current.ptr = (uint8_t *)scan->ptr;
 	scan->current.attr = 0;
-	scan->type = SENT_NONE;
+	scan->type = CORPUS_SENT_NONE;
 
 NoBreak:
 
@@ -205,7 +213,7 @@ CR:
 
 ParaSep:
 	// SB4: ParaSep +
-	scan->type = SENT_PARASEP;
+	scan->type = CORPUS_SENT_PARASEP;
 	goto Break;
 
 UpperLower:
@@ -266,7 +274,7 @@ ATerm_Close_Sp:
 
 	case SENT_BREAK_OLETTER:
 	case SENT_BREAK_UPPER:
-		scan->type = SENT_ATERM;
+		scan->type = CORPUS_SENT_ATERM;
 		goto Break;
 
 	case SENT_BREAK_LOWER:
@@ -289,7 +297,7 @@ ATerm_Close_Sp:
 		if (has_future_lower(scan)) {
 			goto NoBreak;
 		} else {
-			scan->type = SENT_ATERM;
+			scan->type = CORPUS_SENT_ATERM;
 			goto Break;
 		}
 	}
@@ -337,15 +345,15 @@ STerm_Close_Sp:
 		goto ATerm;
 
 	default:
-		scan->type = SENT_STERM;
+		scan->type = CORPUS_SENT_STERM;
 		goto Break;
 	}
 
 Break:
-	scan->current.attr |= (scan->ptr - scan->current.ptr);
+	scan->current.attr |= (size_t)(scan->ptr - scan->current.ptr);
 
-	if (TEXT_SIZE(&scan->current) == 0) {
-		if (TEXT_SIZE(&scan->text) == 0 && !scan->at_end) {
+	if (CORPUS_TEXT_SIZE(&scan->current) == 0) {
+		if (CORPUS_TEXT_SIZE(&scan->text) == 0 && !scan->at_end) {
 			scan->at_end = 1;
 			return 1;
 		} else {
