@@ -25,31 +25,31 @@
 
 static const R_CallMethodDef CallEntries[] = {
 	CALLDEF(anyNA_text, 1),
-	CALLDEF(as_character_jsondata, 1),
+	CALLDEF(as_character_json, 1),
 	CALLDEF(as_character_text, 1),
-	CALLDEF(as_integer_jsondata, 1),
-	CALLDEF(as_double_jsondata, 1),
-	CALLDEF(as_list_jsondata, 3),
-	CALLDEF(as_logical_jsondata, 1),
+	CALLDEF(as_integer_json, 1),
+	CALLDEF(as_double_json, 1),
+	CALLDEF(as_list_json, 3),
+	CALLDEF(as_logical_json, 1),
 	CALLDEF(as_text_character, 1),
-	CALLDEF(as_text_jsondata, 1),
-	CALLDEF(datatype_jsondata, 1),
-	CALLDEF(datatypes_jsondata, 1),
-	CALLDEF(dim_jsondata, 1),
+	CALLDEF(as_text_json, 1),
+	CALLDEF(datatype_json, 1),
+	CALLDEF(datatypes_json, 1),
+	CALLDEF(dim_json, 1),
 	CALLDEF(is_na_text, 1),
-	CALLDEF(length_jsondata, 1),
+	CALLDEF(length_json, 1),
 	CALLDEF(length_text, 1),
 	CALLDEF(logging_off, 0),
 	CALLDEF(logging_on, 0),
 	CALLDEF(mmap_ndjson, 1),
-	CALLDEF(names_jsondata, 1),
-	CALLDEF(print_jsondata, 1),
+	CALLDEF(names_json, 1),
+	CALLDEF(print_json, 1),
 	CALLDEF(read_ndjson, 1),
 	CALLDEF(sentences_text, 1),
-	CALLDEF(simplify_jsondata, 3),
+	CALLDEF(simplify_json, 3),
 	CALLDEF(stopwords, 1),
-	CALLDEF(subscript_jsondata, 2),
-	CALLDEF(subset_jsondata, 3),
+	CALLDEF(subscript_json, 2),
+	CALLDEF(subset_json, 3),
 	CALLDEF(subset_text_handle, 2),
 	CALLDEF(tokens_text, 2),
 	CALLDEF(term_counts_text, 3),
